Roles have been moved
=====================

The Ansible roles ara_api, ara_frontend_nginx as well as ara_web used to live here but have since been moved to an
`Ansible collection <https://github.com/ansible-community/ara-collection>`_.

This collection is also available on `galaxy.ansible.com <https://galaxy.ansible.com/recordsansible/ara>`_.

You can install the collection by running ``ansible-galaxy collection install recordsansible.ara``

This directory will eventually be removed.